==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>Kiểu chỉ báo</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>Chế độ thời trang</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>Chế độ hiệu quả</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>Trái</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>Vị trí</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>Chế độ</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>Định vị trái</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>Định vị trên</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>Định vị giữa</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>Trên</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>Dưới</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>Phải</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>Trạng thái</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>Giữ hiển thị</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>Giữ ẩn</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>Ẩn thông minh</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>Cài đặt thanh đock</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Kiểu chỉ báo</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Chế độ thời trang</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Chế độ hiệu quả</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Phương thức cổ điển</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Phương thức trung tâm</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Trái</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Vị trí</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Chế độ</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Trên</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dưới</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Phải</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Trạng thái</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Giữ hiển thị</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Giữ ẩn</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ẩn thông minh</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Cài đặt thanh đock</translation>
    </message>
</context>
</TS>
